Cluster
========

.. doxygenstruct:: aare::Cluster
   :members:
   :undoc-members:
   :private-members:


**Free Functions:** 

.. doxygenfunction:: aare::reduce_to_3x3(const Cluster<T, ClusterSizeX, ClusterSizeY, CoordType>&)
   
.. doxygenfunction:: aare::reduce_to_2x2(const Cluster<T, ClusterSizeX, ClusterSizeY, CoordType>&)
   